using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using AmazonWrapper.Amazon.ECSWebservice;

public partial class Default2 : System.Web.UI.Page
{
	private string subscriptionId = ConfigurationManager.AppSettings["Amazon.Webservice.SubscriptionId"].ToString();
	private string associateId = ConfigurationManager.AppSettings["Amazon.Associates.ID"].ToString();
	private string asin;

	protected void Page_Load(object sender, EventArgs e)
	{
		asin = Request.QueryString["asin"];
		if (asin != null)
		{
			if (!Page.IsPostBack)
			{
				if ((Session["CartId"] == null) || (Session["CartHMAC"] == null))
				{
					createShoppingCart(asin);
				}
				else
				{
					addItemToShoppingCart(asin);
				}
			}

		}
		else
		{
			getShoppingCart();
		}
	}

	private void createShoppingCart(string asin)
	{
		CartRequest req = new CartRequest();
		
		req.SubscriptionId = subscriptionId;
		req.AssociateTag = associateId;
		
		CartItem[] items = req.CreateCart(asin);
		
		Session["CartId"] = req.CartId;
		Session["CartHMAC"] = req.HMAC;
		bindShoppingCart(items);
		totalPriceLabel.Text = req.SubTotal;
		checkoutHyperLink.NavigateUrl = req.PurchaseURL;
	}


	private void addItemToShoppingCart(string asin)
	{
		CartRequest req = new CartRequest();

		req.SubscriptionId = subscriptionId;
		req.AssociateTag = associateId;
		req.CartId = Session["CartId"].ToString();
		req.HMAC = Session["CartHMAC"].ToString();

		CartItem[] items = req.AddToCart(asin);

		bindShoppingCart(items);

		totalPriceLabel.Text = req.SubTotal;
		checkoutHyperLink.NavigateUrl = req.PurchaseURL;
	}

	private void updateShoppingCart()
	{
		CartRequest req = new CartRequest();

		req.SubscriptionId = subscriptionId;
		req.AssociateTag = associateId;
		req.CartId = Session["CartId"].ToString();
		req.HMAC = Session["CartHMAC"].ToString();

		string[] asinArray = new string[cartRepeater.Items.Count];
		string[] quantityArray = new string[cartRepeater.Items.Count];

		for (int i = 0; i < cartRepeater.Items.Count; i++)
		{
			RepeaterItem item = cartRepeater.Items[i];

			bool delete = ((CheckBox)item.FindControl("removeCheckBox")).Checked;
			string qty = ((TextBox)item.FindControl("quantityTextBox")).Text;
			string itemId = ((System.Web.UI.HtmlControls.HtmlInputHidden)item.FindControl("itemIdInput")).Value;

			if (delete) quantityArray[i] = "0";
			else quantityArray[i] = qty;

			asinArray[i] = itemId;
		}

		CartItem[] items = req.ModifyCart(asinArray, quantityArray);
		bindShoppingCart(items);
		totalPriceLabel.Text = req.SubTotal;
		checkoutHyperLink.NavigateUrl = req.PurchaseURL;
	}

	private void getShoppingCart()
	{
		CartRequest req = new CartRequest();

		req.SubscriptionId = subscriptionId;
		req.AssociateTag = associateId;

		try
		{
			req.CartId = Session["CartId"].ToString();
			req.HMAC = Session["CartHMAC"].ToString();
			CartItem[] items = req.GetCart();

			bindShoppingCart(items);

			totalPriceLabel.Text = req.SubTotal;
			checkoutHyperLink.NavigateUrl = req.PurchaseURL;
		}
		catch 
		{
			lblErrMsg.Text = "Your cart is empty";
		}	
	}

	private void clearShoppingCart()
	{
		CartRequest req = new CartRequest();

		req.SubscriptionId = subscriptionId;
		req.AssociateTag = associateId;
		req.CartId = Session["CartId"].ToString();
		req.HMAC = Session["CartHMAC"].ToString();

		CartItem[] items = req.ClearCart();

		bindShoppingCart(items);

		totalPriceLabel.Text = req.SubTotal;
		checkoutHyperLink.NavigateUrl = req.PurchaseURL;
	}

	private void bindShoppingCart(CartItem[] items)
	{
		DataTable cartTable = new DataTable();
		cartTable.Columns.Add(new DataColumn("ASIN", typeof(string)));
		cartTable.Columns.Add(new DataColumn("CartItemId", typeof(string)));
		cartTable.Columns.Add(new DataColumn("Title", typeof(string)));
		cartTable.Columns.Add(new DataColumn("Price", typeof(string)));
		cartTable.Columns.Add(new DataColumn("ItemTotal", typeof(string)));
		cartTable.Columns.Add(new DataColumn("Quantity", typeof(string)));

		if (items != null)
		{
			foreach (CartItem item in items)
			{
				DataRow row = cartTable.NewRow();
				if (item.Title != null) row["Title"] = item.Title;
				if (item.ASIN != null) row["ASIN"] = item.ASIN;
				if (item.Quantity != null) row["Quantity"] = item.Quantity;
				if (item.Price != null) row["Price"] = item.Price.FormattedPrice;
				if (item.ItemTotal != null) row["ItemTotal"] = item.ItemTotal.FormattedPrice;
				if (item.CartItemId != null) row["CartItemId"] = item.CartItemId;

				cartTable.Rows.Add(row);
			}
		}

		DataView dv = new DataView(cartTable);

		cartRepeater.DataSource = dv;
		cartRepeater.DataBind();

	}
	protected void clearCartBtn_Click(object sender, System.EventArgs e)
	{
		if (cartRepeater.Items.Count > 0) clearShoppingCart();
	}

	protected void updateLinkBtn_Click(object sender, System.EventArgs e)
	{
		if (cartRepeater.Items.Count > 0) updateShoppingCart();
	}
}
